..
  class.rst

ardt.datasets.cuads.CuadsTrial
==============================

.. currentmodule:: ardt.datasets.cuads

.. autoclass:: CuadsTrial
    :members:
    :show-inheritance:
    :inherited-members:
